import { Provider } from '@angular/core';
import { ApolloClient, ApolloQueryResult, WatchQueryOptions, MutationOptions, SubscriptionOptions } from 'apollo-client';
import { Observable } from 'rxjs/Observable';
import { FragmentDefinitionNode } from 'graphql';
import { ApolloQueryObservable } from './ApolloQueryObservable';
import { ClientMapWrapper, ClientWrapper, ClientMap } from './types';
export interface DeprecatedWatchQueryOptions extends WatchQueryOptions {
    fragments?: FragmentDefinitionNode[];
}
/**
 * Base class that handles ApolloClient
 */
export declare class ApolloBase {
    private client;
    constructor(client: ApolloClient);
    watchQuery<T>(options: DeprecatedWatchQueryOptions): ApolloQueryObservable<ApolloQueryResult<T>>;
    query<T>(options: DeprecatedWatchQueryOptions): Observable<ApolloQueryResult<T>>;
    mutate<T>(options: MutationOptions): Observable<ApolloQueryResult<T>>;
    subscribe(options: SubscriptionOptions): Observable<any>;
    getClient(): ApolloClient;
}
/**
 * Container service that works just like the ApolloBase but includes named ApolloClients
 */
export declare class Apollo extends ApolloBase {
    private map;
    constructor(clientMap: ClientMap);
    default(): ApolloBase;
    use(name: string): ApolloBase;
}
/**
 * Invokes a ClientMapWrapper
 */
export declare function getClientMap(configWrapper: ClientMapWrapper): ClientMap;
/**
 * Provides a value for a map and a wrapper
 */
export declare function provideClientMap(configWrapper: ClientMapWrapper | ClientWrapper): Provider[];
/**
 * Provides the Apollo service
 */
export declare const provideApollo: Provider;
export declare function createApollo(clientMap: ClientMap): Apollo;
