var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
import { Injectable } from '@angular/core';
import { rxify } from 'apollo-client-rxjs';
import { ApolloClient } from 'apollo-client';
import { from } from 'rxjs/observable/from';
import { fromPromise } from 'rxjs/observable/fromPromise';
import { ApolloQueryObservable } from './ApolloQueryObservable';
import { CLIENT_MAP, CLIENT_MAP_WRAPPER } from './tokens';
/**
 * Base class that handles ApolloClient
 */
export var ApolloBase = (function () {
    /**
     * @param {?} client
     */
    function ApolloBase(client) {
        this.client = client;
    }
    /**
     * @param {?} options
     * @return {?}
     */
    ApolloBase.prototype.watchQuery = function (options) {
        return new ApolloQueryObservable(rxify(this.client.watchQuery)(options));
    };
    /**
     * @param {?} options
     * @return {?}
     */
    ApolloBase.prototype.query = function (options) {
        return fromPromise(this.client.query(options));
    };
    /**
     * @param {?} options
     * @return {?}
     */
    ApolloBase.prototype.mutate = function (options) {
        return fromPromise(this.client.mutate(options));
    };
    /**
     * @param {?} options
     * @return {?}
     */
    ApolloBase.prototype.subscribe = function (options) {
        return from(this.client.subscribe(options));
    };
    /**
     * @return {?}
     */
    ApolloBase.prototype.getClient = function () {
        return this.client;
    };
    ApolloBase.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    ApolloBase.ctorParameters = function () { return [
        { type: ApolloClient, },
    ]; };
    return ApolloBase;
}());
function ApolloBase_tsickle_Closure_declarations() {
    /** @type {?} */
    ApolloBase.decorators;
    /**
     * @nocollapse
     * @type {?}
     */
    ApolloBase.ctorParameters;
    /** @type {?} */
    ApolloBase.prototype.client;
}
/**
 * Container service that works just like the ApolloBase but includes named ApolloClients
 */
export var Apollo = (function (_super) {
    __extends(Apollo, _super);
    /**
     * @param {?} clientMap
     */
    function Apollo(clientMap) {
        _super.call(this, clientMap['default']);
        this.map = new Map();
        for (var name_1 in clientMap) {
            if (typeof name_1 === 'string' && name_1 !== 'default') {
                this.map.set(name_1, new ApolloBase(clientMap[name_1]));
            }
        }
    }
    /**
     * @return {?}
     */
    Apollo.prototype.default = function () {
        return this;
    };
    /**
     * @param {?} name
     * @return {?}
     */
    Apollo.prototype.use = function (name) {
        if (name === 'default') {
            return this.default();
        }
        return this.map.get(name);
    };
    Apollo.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    Apollo.ctorParameters = function () { return [
        null,
    ]; };
    return Apollo;
}(ApolloBase));
function Apollo_tsickle_Closure_declarations() {
    /** @type {?} */
    Apollo.decorators;
    /**
     * @nocollapse
     * @type {?}
     */
    Apollo.ctorParameters;
    /** @type {?} */
    Apollo.prototype.map;
}
/**
 * Invokes a ClientMapWrapper
 * @param {?} configWrapper
 * @return {?}
 */
export function getClientMap(configWrapper) {
    var /** @type {?} */ config = configWrapper();
    if (config instanceof ApolloClient) {
        return { default: config };
    }
    return config;
}
/**
 * Provides a value for a map and a wrapper
 * @param {?} configWrapper
 * @return {?}
 */
export function provideClientMap(configWrapper) {
    return [{
            provide: CLIENT_MAP_WRAPPER,
            useValue: configWrapper,
        }, {
            provide: CLIENT_MAP,
            useFactory: getClientMap,
            deps: [CLIENT_MAP_WRAPPER],
        }];
}
/**
 * Provides the Apollo service
 */
export var /** @type {?} */ provideApollo = {
    provide: Apollo,
    useFactory: createApollo,
    deps: [CLIENT_MAP],
};
/**
 * @param {?} clientMap
 * @return {?}
 */
export function createApollo(clientMap) {
    return new Apollo(clientMap);
}
//# sourceMappingURL=Apollo.js.map